
# Slot: mixins




URI: [linkml:permissible_value_mixins](https://w3id.org/linkml/permissible_value_mixins)


## Domain and Range

[PermissibleValue](PermissibleValue.md) &#8594;  <sub>0..\*</sub> [PermissibleValue](PermissibleValue.md)

## Parents

 *  is_a: [mixins](mixins.md)

## Children


## Used by

 * [PermissibleValue](PermissibleValue.md)
